Function dicom_dictionary_std::registry
source · [−]pub fn registry() -> &'static StandardDictionaryRegistryExpand description
Retrieve a singleton instance of the standard dictionary registry.
pub fn registry() -> &'static StandardDictionaryRegistryRetrieve a singleton instance of the standard dictionary registry.